@@ -9,6 +9,16 @@ import json
 import csv
 import gzip
 
+class ExtendedS3Hook(S3Hook):
+    """Extends and improves the provider package's S3Hook's capability"""
+
+    credentials_by_region = {}
+
+    def _get_credentials(self, region_name):
+        "Avoid creation of a new session each time an S3 file is downloaded."
+        if not region_name in self.credentials_by_region:
+            self.credentials_by_region[region_name] = super()._get_credentials(region_name=region_name)
+        return self.credentials_by_region[region_name]
 
 class EWAHS3Operator(EWAHBaseOperator):
     """Only implemented for JSON and CSV files from S3 right now!"""
@@ -130,7 +140,7 @@ class EWAHS3Operator(EWAHBaseOperator):
             if data:
                 self.upload_data(data=data)
 
-        hook = S3Hook(self.source_conn.conn_id)
+        hook = ExtendedS3Hook(self.source_conn.conn_id)
         suffix = self.suffix
         if self.key_name:
             obj = hook.get_key(self.key_name, self.bucket_name)
@@ -196,7 +206,7 @@ class EWAHS3Operator(EWAHBaseOperator):
                 chunk_upload(reader)
 
     def execute_json(self, context, f_get_data):
-        hook = S3Hook(self.source_conn.conn_id)
+        hook = ExtendedS3Hook(self.source_conn.conn_id)
         suffix = self.suffix
 
         if self.key_name:
